@@ -110,7 +110,7 @@ namespace Docky.Services
 		void InitializeNetworkManager ()
 		{
 			NetworkConnected = true;
-			if (nmTimer != 0) {
+			if (nmTimer > 0) {
 				GLib.Source.Remove (nmTimer);
 				nmTimer = 0;
 			}
@@ -256,38 +256,32 @@ namespace Docky.Services
 			}
 		}
 		
-		const string PowerManagementName = "org.freedesktop.PowerManagement";
-		const string PowerManagementPath = "/org/freedesktop/PowerManagement";
-		const string DeviceKitPowerName = "org.freedesktop.DeviceKit.Power";
-		const string DeviceKitPowerPath = "/org/freedesktop/DeviceKit/Power";
 		const string UPowerName = "org.freedesktop.UPower";
 		const string UPowerPath = "/org/freedesktop/UPower";
 		
 		delegate void BoolDelegate (bool val);
 		
-		[Interface(PowerManagementName)]
-		interface IPowerManagement
-		{
-			bool GetOnBattery ();
-			event BoolDelegate OnBatteryChanged;
-		}
-		
-		[Interface(DeviceKitPowerName)]
-		interface IDeviceKitPower : org.freedesktop.DBus.Properties
-		{
-			event Action Changed;
-		}
-
 		[Interface(UPowerName)]
 		interface IUPower : org.freedesktop.DBus.Properties
 		{
+			//bool OnBattery { get; }
+
 			event Action Changed;
 		}
 		
+		bool GetBoolean (org.freedesktop.DBus.Properties dbusobj, string path, string propname) 
+		{
+			try {
+				return Boolean.Parse (dbusobj.Get (path, propname).ToString ());
+			} catch (Exception e) {
+				Log.Error ("{0}", e.Message);
+				Log.Debug (e.StackTrace);
+				return false;
+			}
+		}
+
 		bool on_battery;
 		
-		IPowerManagement power;
-		IDeviceKitPower devicekit;
 		IUPower upower;
 		
 		void InitializeBattery ()
@@ -301,16 +295,6 @@ namespace Docky.Services
 					upower.Changed += HandleUPowerChanged;
 					HandleUPowerChanged ();
 					Log<SystemService>.Debug ("Using org.freedesktop.UPower for battery information");
-				} else if (Bus.System.NameHasOwner (DeviceKitPowerName)) {
-					devicekit = Bus.System.GetObject<IDeviceKitPower> (DeviceKitPowerName, new ObjectPath (DeviceKitPowerPath));
-					devicekit.Changed += HandleDeviceKitChanged;
-					HandleDeviceKitChanged ();
-					Log<SystemService>.Debug ("Using org.freedesktop.DeviceKit.Power for battery information");
-				} else if (Bus.Session.NameHasOwner (PowerManagementName)) {
-					power = Bus.Session.GetObject<IPowerManagement> (PowerManagementName, new ObjectPath (PowerManagementPath));
-					power.OnBatteryChanged += PowerOnBatteryChanged;
-					on_battery = power.GetOnBattery ();
-					Log<SystemService>.Debug ("Using org.freedesktop.PowerManager for battery information");
 				}
 			} catch (Exception e) {
 				Log<SystemService>.Error ("Could not initialize power manager dbus: '{0}'", e.Message);
@@ -318,27 +302,9 @@ namespace Docky.Services
 			}
 		}
 
-		void PowerOnBatteryChanged (bool val)
-		{
-			if (on_battery != val) {
-				on_battery = val;
-				OnBatteryStateChanged ();
-			}
-		}
-		
-		void HandleDeviceKitChanged ()
-		{
-			bool newState = (bool) devicekit.Get (DeviceKitPowerName, "OnBattery");
-			
-			if (on_battery != newState) {
-				on_battery = newState;
-				OnBatteryStateChanged ();
-			}
-		}
-
 		void HandleUPowerChanged ()
 		{
-			bool newState = (bool) upower.Get (UPowerName, "OnBattery");
+			bool newState = GetBoolean (upower, UPowerName, "OnBattery");
 			
 			if (on_battery != newState) {
 				on_battery = newState;
