@@ -2,6 +2,7 @@
 //  Copyright (C) 2009 Jason Smith, Robert Dyer
 //  Copyright (C) 2010 Chris Szikszoy
 //  Copyright (C) 2011 Robert Dyer
+//  Copyright (C) 2013 Rico Tzschichholz
 // 
 //  This program is free software: you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -27,8 +28,8 @@ using System.Text;
 using Cairo;
 using Gdk;
 using GLib;
-using Gnome;
 using Gtk;
+using KeyFile;
 using Mono.Unix;
 
 using Docky.Interface;
@@ -122,11 +123,10 @@ namespace Docky
 		
 		void StopTimer ()
 		{
-			if (timer == 0)
-				return;
-			
-			GLib.Source.Remove (timer);
-			timer = 0;
+			if (timer > 0) {
+				GLib.Source.Remove (timer);
+				timer = 0;
+			}
 		}
 		
 		void StartTimer ()
@@ -139,7 +139,10 @@ namespace Docky
 				bool finished = (DateTime.UtcNow - shown_time).TotalMilliseconds / AnimationTime > 1;
 				if (finished && !curtainDown)
 					Hide ();
-				
+
+				if (finished)
+					timer = 0;
+
 				return !finished;
 			});
 		}
@@ -508,34 +511,34 @@ namespace Docky
 		}
 
 		const string AutoStartKey = "Hidden";
-		DesktopItem autostart_item;
+		const string DesktopGroup = "Desktop Entry";
+		GKeyFile autostart_keyfile;
 		bool AutoStart 
 		{
 			get {
-				if (autostart_item == null) {
+				if (autostart_keyfile == null) {
 					
 					GLib.File autostart_file = DockServices.Paths.AutoStartFile;
 					
 					try {
-						autostart_item = DesktopItem.NewFromFile (autostart_file.Path, DesktopItemLoadFlags.NoTranslations);
-						if (autostart_item.AttrExists (AutoStartKey))
-							return !String.Equals (autostart_item.GetString (AutoStartKey), "true", StringComparison.OrdinalIgnoreCase);
+						autostart_keyfile = new GKeyFile (autostart_file.Path, KeyFile.Flags.None);
+						if (autostart_keyfile.HasKey (DesktopGroup, AutoStartKey))
+							return !String.Equals (autostart_keyfile.GetString (DesktopGroup, AutoStartKey), "true", StringComparison.OrdinalIgnoreCase);
 						
 					} catch (GLib.GException loadException) {
-						Log<ConfigurationWindow>.Info ("Unable to load existing autostart file: {0}", loadException.Message);					
+						Log<ConfigurationWindow>.Info ("Unable to load existing autostart file: {0}", loadException.Message);
 						Log<SystemService>.Error ("Could not open autostart file {0}", autostart_file.Path);
 						
 						GLib.File desktop_file = DesktopFile;
 						
 						if (desktop_file.Exists) {
 							Log<ConfigurationWindow>.Info ("Writing new autostart file to {0}", autostart_file.Path);
-							autostart_item = DesktopItem.NewFromFile (desktop_file.Path, DesktopItemLoadFlags.NoTranslations);
+							autostart_keyfile = new GKeyFile (desktop_file.Path, KeyFile.Flags.None);
 							try {
 								if (!autostart_file.Parent.Exists)
-									autostart_file.Parent.MakeDirectoryWithParents (null);						
+									autostart_file.Parent.MakeDirectoryWithParents (null);
 						
-								autostart_item.Save (autostart_file.StringUri (), true);
-								autostart_item.Location = autostart_file.StringUri ();
+								autostart_keyfile.Save (autostart_file.Path);
 								return true;
 								
 							} catch (Exception e) {
@@ -545,16 +548,20 @@ namespace Docky
 						return false;
 					}
 				}
-				if (autostart_item.AttrExists (AutoStartKey))
-					return !String.Equals (autostart_item.GetString (AutoStartKey), "true", StringComparison.OrdinalIgnoreCase);
+				if (autostart_keyfile.HasKey (DesktopGroup, AutoStartKey))
+					return !String.Equals (autostart_keyfile.GetString (DesktopGroup, AutoStartKey), "true", StringComparison.OrdinalIgnoreCase);
 				else
 					return true;
 			}
 			set {
-				if (autostart_item != null) {
-					autostart_item.SetBoolean (AutoStartKey, !value);
+				if (autostart_keyfile != null) {
+					autostart_keyfile.SetBoolean (DesktopGroup, AutoStartKey, !value);
 					try {
-						autostart_item.Save (null, true);
+						GLib.File autostart_file = DockServices.Paths.AutoStartFile;
+						if (!autostart_file.Parent.Exists)
+							autostart_file.Parent.MakeDirectoryWithParents (null);
+
+						autostart_keyfile.Save (autostart_file.Path);
 					} catch (Exception e) {
 						Log<SystemService>.Error ("Failed to update autostart file: {0}", e.Message);
 					}
